[PATCH 14/20] drm/amd/display: Update BW ALLOCATION Function declaration

Qingqing Zhuo qingqing.zhuo at amd.com
Wed Feb 22 06:40:35 UTC 2023


From: Mustapha Ghaddar <mghaddar at amd.com>

[WHY & HOW]
Update the declaration to give a better idea of what the
function does.

Reviewed-by: Wenjing Liu <Wenjing.Liu at amd.com>
Acked-by: Qingqing Zhuo <qingqing.zhuo at amd.com>
Signed-off-by: Mustapha Ghaddar <mghaddar at amd.com>
---
 drivers/gpu/drm/amd/display/dc/dc_link.h                    | 6 +++---
 .../gpu/drm/amd/display/dc/link/protocols/link_dp_dpia_bw.c | 2 +-
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/amd/display/dc/link/protocols/link_dp_dpia_bw.c b/drivers/gpu/drm/amd/display/dc/link/protocols/link_dp_dpia_bw.c
index 9d3df69fc340..72ff0ae44d01 100644
--- a/drivers/gpu/drm/amd/display/dc/link/protocols/link_dp_dpia_bw.c
+++ b/drivers/gpu/drm/amd/display/dc/link/protocols/link_dp_dpia_bw.c
@@ -300,7 +300,7 @@ bool link_dp_dpia_set_dptx_usb4_bw_alloc_support(struct dc_link *link)
 out:
 	return ret;
 }
-void dc_link_get_usb4_req_bw_resp(struct dc_link *link, uint8_t bw, uint8_t result)
+void dc_link_handle_usb4_bw_alloc_response(struct dc_link *link, uint8_t bw, uint8_t result)
 {
 	if (!get_bw_alloc_proceed_flag((link)))
 		return;
diff --git a/drivers/gpu/drm/amd/display/dc/dc_link.h b/drivers/gpu/drm/amd/display/dc/dc_link.h
index bfe0f6877d9e..80e18c770cda 100644
--- a/drivers/gpu/drm/amd/display/dc/dc_link.h
+++ b/drivers/gpu/drm/amd/display/dc/dc_link.h
@@ -549,8 +549,8 @@ void dc_link_edp_panel_backlight_power_on(struct dc_link *link,
 void dc_link_set_usb4_req_bw_req(struct dc_link *link, int req_bw);
 
 /*
  * CB function for when the status of the Req above is complete. We will
  * find out the result of allocating on CM and update structs accordingly
  *
  * @link: pointer to the dc_link struct instance
  * @bw: Allocated or Estimated BW depending on the result
@@ -558,7 +558,7 @@ void dc_link_set_usb4_req_bw_req(struct dc_link *link, int req_bw);
  *
  * return: none
  */
-void dc_link_get_usb4_req_bw_resp(struct dc_link *link, uint8_t bw, uint8_t result);
+void dc_link_handle_usb4_bw_alloc_response(struct dc_link *link, uint8_t bw, uint8_t result);
 
 /*
  * Handle the USB4 BW Allocation related functionality here:
@@ -549,8 +549,8 @@ void dc_link_edp_panel_backlight_power_on(struct dc_link *link,
 
 /*
- * CB function for when the status of the Req above is complete. We will
- * find out the result of allocating on CM and update structs accordingly
+ * Handle function for when the status of the Request above is complete.
+ * We will find out the result of allocating on CM and update structs.
  *
  * @link: pointer to the dc_link struct instance
-- 
2.34.1



More information about the amd-gfx mailing list